==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TCPRouteRuleFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPRouteRuleFluent<A extends TCPRouteRuleFluent<A>> extends Fluent<A>{
  public A addToBackendRefs(Integer index,BackendRef item);
  public A setToBackendRefs(Integer index,BackendRef item);
  public A addToBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.BackendRef... items);
  public A addAllToBackendRefs(Collection<BackendRef> items);
  public A removeFromBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.BackendRef... items);
  public A removeAllFromBackendRefs(Collection<BackendRef> items);
  public A removeMatchingFromBackendRefs(Predicate<BackendRefBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBackendRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<BackendRef> getBackendRefs();
  public List<BackendRef> buildBackendRefs();
  public BackendRef buildBackendRef(Integer index);
  public BackendRef buildFirstBackendRef();
  public BackendRef buildLastBackendRef();
  public BackendRef buildMatchingBackendRef(Predicate<BackendRefBuilder> predicate);
  public Boolean hasMatchingBackendRef(Predicate<BackendRefBuilder> predicate);
  public A withBackendRefs(List<BackendRef> backendRefs);
  public A withBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.BackendRef... backendRefs);
  public Boolean hasBackendRefs();
  public TCPRouteRuleFluent.BackendRefsNested<A> addNewBackendRef();
  public TCPRouteRuleFluent.BackendRefsNested<A> addNewBackendRefLike(BackendRef item);
  public TCPRouteRuleFluent.BackendRefsNested<A> setNewBackendRefLike(Integer index,BackendRef item);
  public TCPRouteRuleFluent.BackendRefsNested<A> editBackendRef(Integer index);
  public TCPRouteRuleFluent.BackendRefsNested<A> editFirstBackendRef();
  public TCPRouteRuleFluent.BackendRefsNested<A> editLastBackendRef();
  public TCPRouteRuleFluent.BackendRefsNested<A> editMatchingBackendRef(Predicate<BackendRefBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BackendRefsNested<N> extends Nested<N>,BackendRefFluent<TCPRouteRuleFluent.BackendRefsNested<N>>{
    public N and();
    public N endBackendRef();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TCPRouteRuleFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.BackendRefBuilder;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.BackendRefFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.BackendRef;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPRouteRuleFluent<A extends TCPRouteRuleFluent<A>> extends Fluent<A>{
  public A addToBackendRefs(Integer index,BackendRef item);
  public A setToBackendRefs(Integer index,BackendRef item);
  public A addToBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.BackendRef... items);
  public A addAllToBackendRefs(Collection<BackendRef> items);
  public A removeFromBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.BackendRef... items);
  public A removeAllFromBackendRefs(Collection<BackendRef> items);
  public A removeMatchingFromBackendRefs(Predicate<BackendRefBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBackendRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<BackendRef> getBackendRefs();
  public List<BackendRef> buildBackendRefs();
  public BackendRef buildBackendRef(Integer index);
  public BackendRef buildFirstBackendRef();
  public BackendRef buildLastBackendRef();
  public BackendRef buildMatchingBackendRef(Predicate<BackendRefBuilder> predicate);
  public Boolean hasMatchingBackendRef(Predicate<BackendRefBuilder> predicate);
  public A withBackendRefs(List<BackendRef> backendRefs);
  public A withBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.BackendRef... backendRefs);
  public Boolean hasBackendRefs();
  public TCPRouteRuleFluent.BackendRefsNested<A> addNewBackendRef();
  public TCPRouteRuleFluent.BackendRefsNested<A> addNewBackendRefLike(BackendRef item);
  public TCPRouteRuleFluent.BackendRefsNested<A> setNewBackendRefLike(Integer index,BackendRef item);
  public TCPRouteRuleFluent.BackendRefsNested<A> editBackendRef(Integer index);
  public TCPRouteRuleFluent.BackendRefsNested<A> editFirstBackendRef();
  public TCPRouteRuleFluent.BackendRefsNested<A> editLastBackendRef();
  public TCPRouteRuleFluent.BackendRefsNested<A> editMatchingBackendRef(Predicate<BackendRefBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BackendRefsNested<N> extends Nested<N>,BackendRefFluent<TCPRouteRuleFluent.BackendRefsNested<N>>{
    public N and();
    public N endBackendRef();
    
  }
  
}
